@@ -13,7 +13,7 @@ module IceCube
       true
     end
 
-    def next_time(t, schedule, closing_time)
+    def next_time(t, _, closing_time)
       unless closing_time && closing_time < t
         time if time.to_i >= t.to_i
       end
@@ -23,6 +23,10 @@ module IceCube
       { :time => time }
     end
 
+    def full_required?
+      false
+    end
+
   end
 
 end
