@@ -4,18 +4,28 @@ module IceCube
 
     def minute_of_hour(*minutes)
       minutes.flatten.each do |minute|
-        unless minute.is_a?(Fixnum)
-          raise ArgumentError, "expecting Fixnum value for minute, got #{minute.inspect}"
+        unless minute.is_a?(Integer)
+          raise ArgumentError, "expecting Integer value for minute, got #{minute.inspect}"
         end
+
+        verify_alignment(minute, :min, :minute_of_hour) { |error| raise error }
+
         validations_for(:minute_of_hour) << Validation.new(minute)
       end
       clobber_base_validations(:min)
       self
     end
 
-    class Validation
+    def realign(opening_time, start_time)
+      return super unless validations[:minute_of_hour]
 
-      include Validations::Lock
+      first_minute = validations[:minute_of_hour].min_by(&:value)
+      time = TimeUtil::TimeWrapper.new(start_time, false)
+      time.min = first_minute.value
+      super opening_time, time.to_time
+    end
+
+    class Validation < Validations::FixedValue
 
       attr_reader :minute
       alias :value :minute
@@ -24,6 +34,10 @@ module IceCube
         @minute = minute
       end
 
+      def key
+        :minute_of_hour
+      end
+
       def type
         :min
       end
@@ -45,8 +59,8 @@ module IceCube
       end
 
       StringBuilder.register_formatter(:minute_of_hour) do |segments|
-        str = "on the #{StringBuilder.sentence(segments)} "
-        str << (segments.size == 1 ? 'minute of the hour' : 'minutes of the hour')
+        str = StringBuilder.sentence(segments)
+        IceCube::I18n.t('ice_cube.on_minutes_of_hour', count: segments.size, segments: str)
       end
 
     end
