@@ -4,19 +4,18 @@ module IceCube
 
     def month_of_year(*months)
       months.flatten.each do |month|
-        unless month.is_a?(Fixnum) || month.is_a?(Symbol)
-          raise ArgumentError, "expecting Fixnum or Symbol value for month, got #{month.inspect}"
+        unless month.is_a?(Integer) || month.is_a?(Symbol)
+          raise ArgumentError, "expecting Integer or Symbol value for month, got #{month.inspect}"
         end
         month = TimeUtil.sym_to_month(month)
+        verify_alignment(month, :month, :month_of_year) { |error| raise error }
         validations_for(:month_of_year) << Validation.new(month)
       end
       clobber_base_validations :month
       self
     end
 
-    class Validation
-
-      include Validations::Lock
+    class Validation < Validations::FixedValue
 
       attr_reader :month
       alias :value :month
@@ -25,6 +24,10 @@ module IceCube
         @month = month
       end
 
+      def key
+        :month_of_year
+      end
+
       def type
         :month
       end
@@ -34,7 +37,7 @@ module IceCube
       end
 
       def build_s(builder)
-        builder.piece(:month_of_year) << Date::MONTHNAMES[month]
+        builder.piece(:month_of_year) << IceCube::I18n.t("date.month_names")[month]
       end
 
       def build_hash(builder)
@@ -46,7 +49,7 @@ module IceCube
       end
 
       StringBuilder.register_formatter(:month_of_year) do |segments|
-        "in #{StringBuilder.sentence(segments)}"
+        IceCube::I18n.t("ice_cube.in", target: StringBuilder.sentence(segments))
       end
 
     end
