@@ -12,9 +12,7 @@ module IceCube
       end
     end
 
-    class Validation
-
-      include Validations::Lock
+    class Validation < Validations::FixedValue
 
       attr_reader :type, :value
 
@@ -22,6 +20,10 @@ module IceCube
         @type = type
       end
 
+      def key
+        :base
+      end
+
       def dst_adjust?
         case @type
         when :sec, :min then false
