@@ -4,18 +4,28 @@ module IceCube
 
     def second_of_minute(*seconds)
       seconds.flatten.each do |second|
-      unless second.is_a?(Fixnum)
-        raise ArgumentError, "Expecting Fixnum value for second, got #{second.inspect}"
-      end
+        unless second.is_a?(Integer)
+          raise ArgumentError, "Expecting Integer value for second, got #{second.inspect}"
+        end
+
+        verify_alignment(second, :sec, :second_of_minute) { |error| raise error }
+
         validations_for(:second_of_minute) << Validation.new(second)
       end
       clobber_base_validations :sec
       self
     end
 
-    class Validation
+    def realign(opening_time, start_time)
+      return super unless validations[:second_of_minute]
 
-      include Validations::Lock
+      first_second = Array(validations[:second_of_minute]).min_by(&:value)
+      time = TimeUtil::TimeWrapper.new(start_time, false)
+      time.sec = first_second.value
+      super opening_time, time.to_time
+    end
+
+    class Validation < Validations::FixedValue
 
       attr_reader :second
       alias :value :second
@@ -24,6 +34,10 @@ module IceCube
         @second = second
       end
 
+      def key
+        :second_of_minute
+      end
+
       def type
         :sec
       end
@@ -45,8 +59,8 @@ module IceCube
       end
 
       StringBuilder.register_formatter(:second_of_minute) do |segments|
-        str = "on the #{StringBuilder.sentence(segments)} "
-        str << (segments.size == 1 ? 'second of the minute' : 'seconds of the minute')
+        str = StringBuilder.sentence(segments)
+        IceCube::I18n.t('ice_cube.on_seconds_of_minute', count: segments.size, segments: str)
       end
 
     end
