@@ -3,6 +3,8 @@ module IceCube
   module Validations::SecondlyInterval
 
     def interval(interval)
+      verify_alignment(interval, :sec, :interval) { |error| raise error }
+
       @interval = normalized_interval(interval)
       replace_validations_for(:interval, [Validation.new(@interval)])
       clobber_base_validations(:sec)
@@ -25,14 +27,14 @@ module IceCube
         false
       end
 
-      def validate(step_time, schedule)
-        seconds = step_time.to_i - schedule.start_time.to_i
+      def validate(step_time, start_time)
+        seconds = step_time.to_i - start_time.to_i
         offset = (seconds % interval).nonzero?
         interval - offset if offset
       end
 
       def build_s(builder)
-        builder.base = interval == 1 ? 'Secondly' : "Every #{interval} seconds"
+        builder.base = IceCube::I18n.t("ice_cube.each_second", count: interval)
       end
 
       def build_hash(builder)
