@@ -10,16 +10,26 @@ module IceCube
 
       let(:hash) { {start_time: t, duration: 3600} }
 
-      its(:start_time) { should == t }
-      its(:duration)   { should == 3600 }
+      describe '#start_time' do
+        subject { super().start_time }
+        it { is_expected.to eq(t) }
+      end
+
+      describe '#duration' do
+        subject { super().duration }
+        it { is_expected.to eq(3600) }
+      end
 
       describe "end_time overrules duration" do
         let(:hash) { {start_time: t, end_time: t + 1800, duration: 3600} }
-        its(:duration) { should == 1800 }
+
+        describe '#duration' do
+          subject { super().duration }
+          it { is_expected.to eq(1800) }
+        end
       end
     end
 
 
   end
 end
-
