@@ -1,4 +1,5 @@
 require File.dirname(__FILE__) + '/../spec_helper'
+require 'benchmark'
 
 describe IceCube::Schedule do
 
@@ -9,28 +10,36 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new do |s|
       s.start_time = t1
     end
-    schedule.start_time.should == t1
+    expect(schedule.start_time).to eq(t1)
   end
 
   it 'initializes with a start_time' do
     t1 = Time.local(2013, 2, 14, 0, 32, 0)
     schedule = IceCube::Schedule.new(t1)
-    schedule.start_time.should be_a Time
-    schedule.start_time.should == t1
+    expect(schedule.start_time).to be_a Time
+    expect(schedule.start_time).to eq(t1)
   end
 
-  it 'converts initialized DateTime to Time' do
+  it 'converts initialized DateTime to Time', expect_warnings: true do
     dt = DateTime.new(2013, 2, 14, 0, 32, 0)
     schedule = IceCube::Schedule.new(dt)
-    schedule.start_time.should be_a Time
-    schedule.start_time.should == Time.local(dt.year, dt.month, dt.day, dt.hour, dt.min, dt.sec)
+    expect(schedule.start_time).to be_a Time
+    expect(schedule.start_time).to eq(Time.local(dt.year, dt.month, dt.day, dt.hour, dt.min, dt.sec))
   end
 
   describe :next_occurrence do
 
     it 'should not raise an exception when calling next occurrence with no remaining occurrences' do
       schedule = IceCube::Schedule.new Time.now
-      lambda { schedule.next_occurrence }.should_not raise_error
+      expect { schedule.next_occurrence }.not_to raise_error
+    end
+
+    it "should not skip ahead a day when called with a date" do
+      schedule = IceCube::Schedule.new(Time.utc(2014, 1, 1, 12, 34, 56)) do |s|
+        s.add_recurrence_rule IceCube::Rule.hourly
+      end
+      next_hour = schedule.next_occurrence(Date.new(2014, 1, 2))
+      expect( next_hour ).to eq Time.utc(2014, 1, 2, 00, 34 , 56)
     end
 
   end
@@ -40,16 +49,30 @@ describe IceCube::Schedule do
     it 'should be based on end_time' do
       start = Time.now
       schedule = IceCube::Schedule.new(start)
-      schedule.duration.should == 0
+      expect(schedule.duration).to eq(0)
       schedule.end_time = start + 3600
-      schedule.duration.should == 3600
+      expect(schedule.duration).to eq(3600)
     end
 
     it 'should give precedence to :end_time option' do
       start = Time.now
       conflicting_options = {:end_time => start + 600, :duration => 1200}
       schedule = IceCube::Schedule.new(start, conflicting_options)
-      schedule.duration.should == 600
+      expect(schedule.duration).to eq(600)
+    end
+
+  end
+
+  describe :occurring_at? do
+
+    it "should not capture multiple days when called with a date" do
+      schedule = IceCube::Schedule.new do |s|
+        s.start_time = Time.utc(2013, 12, 31, 23, 59, 50)
+        s.duration = 20
+        s.add_recurrence_rule IceCube::Rule.daily(2)
+      end
+      expect( schedule.occurring_at?(Date.new(2014, 1, 1)) ).to eq true
+      expect( schedule.occurring_at?(Date.new(2014, 1, 2)) ).to eq false
     end
 
   end
@@ -57,19 +80,19 @@ describe IceCube::Schedule do
   describe :recurrence_times do
 
     it 'should start empty' do
-      IceCube::Schedule.new.recurrence_times.should be_empty
+      expect(IceCube::Schedule.new.recurrence_times).to be_empty
     end
 
     it 'should include added times' do
       schedule = IceCube::Schedule.new(t0 = Time.now)
       schedule.add_recurrence_time(t1 = t0 + 3600)
-      schedule.recurrence_times.should == [t1]
+      expect(schedule.recurrence_times).to eq([t1])
     end
 
     it 'can include start time' do
       schedule = IceCube::Schedule.new(t0 = Time.now)
       schedule.add_recurrence_time(t0)
-      schedule.recurrence_times.should == [t0]
+      expect(schedule.recurrence_times).to eq([t0])
     end
 
   end
@@ -82,9 +105,9 @@ describe IceCube::Schedule do
         schedule.rrule IceCube::Rule.daily
         schedule
       end
-      lambda do
+      expect do
         schedules.first.conflicts_with?(schedules.last)
-      end.should raise_error ArgumentError
+      end.to raise_error(ArgumentError)
     end
 
     it 'should not raise error if both are non-terminating closing time present' do
@@ -92,9 +115,9 @@ describe IceCube::Schedule do
       schedule1.rrule IceCube::Rule.weekly
       schedule2 = IceCube::Schedule.new Time.now
       schedule2.rrule IceCube::Rule.weekly
-      lambda do
+      expect do
         schedule1.conflicts_with?(schedule2, Time.now + IceCube::ONE_DAY)
-      end.should_not raise_error
+      end.not_to raise_error
     end
 
     it 'should not raise an error if one is non-terminating' do
@@ -102,9 +125,9 @@ describe IceCube::Schedule do
       schedule1.rrule IceCube::Rule.weekly
       schedule2 = IceCube::Schedule.new Time.now
       schedule2.rrule IceCube::Rule.weekly.until(Time.now)
-      lambda do
+      expect do
         schedule1.conflicts_with?(schedule2)
-      end.should_not raise_error
+      end.not_to raise_error
     end
 
     it 'should not raise an error if the other is non-terminating' do
@@ -112,9 +135,9 @@ describe IceCube::Schedule do
       schedule1.rrule IceCube::Rule.weekly.until(Time.now)
       schedule2 = IceCube::Schedule.new Time.now
       schedule2.rrule IceCube::Rule.weekly
-      lambda do
+      expect do
         schedule1.conflicts_with?(schedule2)
-      end.should_not raise_error
+      end.not_to raise_error
     end
 
     it 'should return true if conflict is present' do
@@ -124,7 +147,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time)
       schedule2.rrule IceCube::Rule.daily
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_DAY)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return false if conflict is not present' do
@@ -134,7 +157,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time)
       schedule2.rrule IceCube::Rule.weekly.day(:monday)
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_DAY)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
     it 'should return true if conflict is present based on duration' do
@@ -144,7 +167,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time)
       schedule2.rrule IceCube::Rule.weekly.day(:tuesday)
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_WEEK)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return true if conflict is present based on duration - other way' do
@@ -154,7 +177,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time, :duration => IceCube::ONE_DAY + 1)
       schedule2.rrule IceCube::Rule.weekly.day(:monday)
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_WEEK)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return false if conflict is past closing_time' do
@@ -163,10 +186,10 @@ describe IceCube::Schedule do
       schedule1.rrule IceCube::Rule.weekly.day(:friday)
       schedule2 = IceCube::Schedule.new(start_time)
       schedule2.rrule IceCube::Rule.weekly.day(:friday)
-      schedule2.conflicts_with?(schedule1, start_time + IceCube::ONE_WEEK).
-        should be_true
-      schedule2.conflicts_with?(schedule1, start_time + IceCube::ONE_DAY).
-        should be_false
+      expect(schedule2.conflicts_with?(schedule1, start_time + IceCube::ONE_WEEK)).
+        to be_truthy
+      expect(schedule2.conflicts_with?(schedule1, start_time + IceCube::ONE_DAY)).
+        to be_falsey
     end
 
     it 'should return false if conflict is not present based on duration' do
@@ -176,7 +199,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time, :duration => IceCube::ONE_HOUR)
       schedule2.rrule IceCube::Rule.weekly.day(:tuesday)
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_WEEK)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
     it 'should return false if conflict is not present on same day based on duration' do
@@ -186,7 +209,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + 3600, :duration => IceCube::ONE_HOUR)
       schedule2.rrule IceCube::Rule.daily
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_WEEK)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
     it 'should return true if conflict is present on same day based on duration' do
@@ -196,7 +219,7 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + 600, :duration => IceCube::ONE_HOUR)
       schedule2.rrule IceCube::Rule.daily
       conflict = schedule1.conflicts_with?(schedule2, start_time + IceCube::ONE_WEEK)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return true if conflict is present and no recurrence' do
@@ -206,9 +229,9 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + 600, :duration => IceCube::ONE_HOUR)
       schedule2.add_recurrence_time(start_time + 600)
       conflict = schedule1.conflicts_with?(schedule2)
-      conflict.should be_true
+      expect(conflict).to be_truthy
       conflict = schedule2.conflicts_with?(schedule1)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return false if conflict is not present and no recurrence' do
@@ -218,9 +241,9 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + IceCube::ONE_HOUR, :duration => IceCube::ONE_HOUR)
       schedule2.add_recurrence_time(start_time + IceCube::ONE_HOUR)
       conflict = schedule1.conflicts_with?(schedule2)
-      conflict.should be_false
+      expect(conflict).to be_falsey
       conflict = schedule2.conflicts_with?(schedule1)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
     it 'should return false if conflict is not present and single recurrence' do
@@ -230,9 +253,9 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + IceCube::ONE_HOUR, :duration => IceCube::ONE_HOUR)
       schedule2.rrule IceCube::Rule.daily
       conflict = schedule1.conflicts_with?(schedule2)
-      conflict.should be_false
+      expect(conflict).to be_falsey
       conflict = schedule2.conflicts_with?(schedule1)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
    it 'should return true if conflict is present and single recurrence' do
@@ -242,9 +265,9 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + 600, :duration => IceCube::ONE_HOUR)
       schedule2.rrule IceCube::Rule.daily
       conflict = schedule1.conflicts_with?(schedule2)
-      conflict.should be_true
+      expect(conflict).to be_truthy
       conflict = schedule2.conflicts_with?(schedule1)
-      conflict.should be_true
+      expect(conflict).to be_truthy
     end
 
     it 'should return false if conflict is not present and single recurrence and time originally specified as Time' do
@@ -254,9 +277,9 @@ describe IceCube::Schedule do
       schedule2 = IceCube::Schedule.new(start_time + IceCube::ONE_HOUR, :duration => IceCube::ONE_HOUR)
       schedule2.add_recurrence_time(start_time + IceCube::ONE_HOUR)
       conflict = schedule1.conflicts_with?(schedule2)
-      conflict.should be_false
+      expect(conflict).to be_falsey
       conflict = schedule2.conflicts_with?(schedule1)
-      conflict.should be_false
+      expect(conflict).to be_falsey
     end
 
   end
@@ -273,12 +296,12 @@ describe IceCube::Schedule do
         i += 1
         break if i > 9
       end
-      answers.should == schedule.first(10)
+      expect(answers).to eq(schedule.first(10))
     end
 
     it 'should return self' do
       schedule = IceCube::Schedule.new
-      schedule.each_occurrence { |s| }.should == schedule
+      expect(schedule.each_occurrence { |s| }).to eq(schedule)
     end
 
     it 'should stop itself when hitting the end of a schedule' do
@@ -287,7 +310,7 @@ describe IceCube::Schedule do
       schedule.add_recurrence_time t1
       answers = []
       schedule.each_occurrence { |t| answers << t }
-      answers.should == [t0, t1]
+      expect(answers).to eq([t0, t1])
     end
 
   end
@@ -296,7 +319,7 @@ describe IceCube::Schedule do
     it 'should be equivalent to all_occurrences in terms of arrays' do
       schedule = IceCube::Schedule.new(Time.now, :duration => IceCube::ONE_HOUR)
       schedule.add_recurrence_rule IceCube::Rule.daily.until(Time.now + 3 * IceCube::ONE_DAY)
-      schedule.all_occurrences == schedule.all_occurrences_enumerator.to_a 
+      schedule.all_occurrences == schedule.all_occurrences_enumerator.to_a
     end
   end
 
@@ -304,7 +327,7 @@ describe IceCube::Schedule do
     it 'should be equivalent to remaining_occurrences in terms of arrays' do
       schedule = IceCube::Schedule.new(Time.now, :duration => IceCube::ONE_HOUR)
       schedule.add_recurrence_rule IceCube::Rule.daily.until(Time.now + 3 * IceCube::ONE_DAY)
-      schedule.remaining_occurrences == schedule.remaining_occurrences_enumerator.to_a 
+      schedule.remaining_occurrences == schedule.remaining_occurrences_enumerator.to_a
     end
   end
 
@@ -313,39 +336,39 @@ describe IceCube::Schedule do
     it 'has end times for each occurrence' do
       schedule = IceCube::Schedule.new(Time.now, :duration => IceCube::ONE_HOUR)
       schedule.add_recurrence_rule IceCube::Rule.daily.until(Time.now + 3 * IceCube::ONE_DAY)
-      schedule.all_occurrences.all? { |o| o.end_time.should == o + IceCube::ONE_HOUR }
+      schedule.all_occurrences.all? { |o| expect(o.end_time).to eq(o + IceCube::ONE_HOUR) }
     end
 
     it 'should include its start time when empty' do
       schedule = IceCube::Schedule.new(t0 = Time.now)
-      schedule.all_occurrences.should == [t0]
+      expect(schedule.all_occurrences).to eq([t0])
     end
 
    it 'should have one occurrence with one recurrence time at start_time' do
       schedule = IceCube::Schedule.new(t0 = Time.local(2012, 12, 12, 12, 12, 12))
       schedule.add_recurrence_time t0
-      schedule.all_occurrences.should == [t0]
+      expect(schedule.all_occurrences).to eq([t0])
     end
 
     it 'should have two occurrences with a recurrence time after start_time' do
       schedule = IceCube::Schedule.new(t0 = Time.local(2012, 12, 12, 12, 12, 12))
       schedule.add_recurrence_time t1 = Time.local(2013,  1, 13,  1, 13,  1)
-      schedule.all_occurrences.should == [t0, t1]
+      expect(schedule.all_occurrences).to eq([t0, t1])
     end
 
     it 'should return an error if there is nothing to stop it' do
       schedule = IceCube::Schedule.new
       schedule.rrule IceCube::Rule.daily
-      lambda do
+      expect do
         schedule.all_occurrences
-      end.should raise_error ArgumentError
+      end.to raise_error(ArgumentError)
     end
 
     it 'should consider count limits separately for multiple rules' do
       schedule = IceCube::Schedule.new
       schedule.rrule IceCube::Rule.minutely.count(3)
       schedule.rrule IceCube::Rule.daily.count(3)
-      schedule.all_occurrences.size.should == 5
+      expect(schedule.all_occurrences.size).to eq(5)
     end
 
   end
@@ -360,10 +383,10 @@ describe IceCube::Schedule do
       schedule.rrule IceCube::Rule.daily(1)
       schedule.extime start_time + IceCube::ONE_DAY
       occurrences = schedule.next_occurrences(2, start_time) # 3 occurrences in the next year
-      occurrences.should == [
+      expect(occurrences).to eq([
         start_time + IceCube::ONE_DAY * 2,
         start_time + IceCube::ONE_DAY * 3
-      ]
+      ])
     end
 
     it 'should be empty if nothing is found before closing time' do
@@ -372,7 +395,16 @@ describe IceCube::Schedule do
         s.add_recurrence_rule nonsense.until(next_year)
       end
       trap_infinite_loop_beyond(24)
-      schedule.next_occurrences(1).should be_empty
+      expect(schedule.next_occurrences(1)).to be_empty
+    end
+
+    it "should not skip ahead a day when called with a date" do
+      schedule = IceCube::Schedule.new(Time.utc(2014, 1, 1, 12, 34, 56)) do |s|
+        s.add_recurrence_rule IceCube::Rule.hourly
+      end
+      next_hours = schedule.next_occurrences(2, Date.new(2014, 1, 2))
+      expect( next_hours ).to eq [Time.utc(2014, 1, 2, 00, 34 , 56),
+                                  Time.utc(2014, 1, 2, 01, 34 , 56)]
     end
 
   end
@@ -385,7 +417,7 @@ describe IceCube::Schedule do
       schedule.rrule IceCube::Rule.daily(1)
       schedule.extime start_time + IceCube::ONE_DAY
       occurrence = schedule.next_occurrence(start_time) # 3 occurrences in the next year
-      occurrence.should == start_time + IceCube::ONE_DAY * 2
+      expect(occurrence).to eq(start_time + IceCube::ONE_DAY * 2)
     end
 
     it 'should respect time zone info for a local future time [#115]' do
@@ -420,14 +452,91 @@ describe IceCube::Schedule do
 
   end
 
+  describe :spans do
+
+    it 'should find occurrence in past with duration beyond the start time' do
+      t0 = Time.utc(2015, 10, 1, 15, 31)
+      schedule = IceCube::Schedule.new(t0, :duration => 2 * IceCube::ONE_HOUR)
+      schedule.add_recurrence_rule IceCube::Rule.daily
+      next_occ = schedule.next_occurrence(t0 + IceCube::ONE_HOUR, :spans => true)
+      expect(next_occ).to eq(t0)
+    end
+
+    it 'should include occurrence in past with duration beyond the start time' do
+      t0 = Time.utc(2015, 10, 1, 15, 31)
+      schedule = IceCube::Schedule.new(t0, :duration => 2 * IceCube::ONE_HOUR)
+      schedule.add_recurrence_rule IceCube::Rule.daily.count(2)
+      occs = schedule.next_occurrences(10, t0 + IceCube::ONE_HOUR, :spans => true)
+      expect(occs).to eq([t0, t0 + IceCube::ONE_DAY])
+    end
+
+    it 'should allow duration span on remaining_occurrences' do
+      t0 = Time.utc(2015, 10, 1, 00, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_DAY)
+      schedule.add_recurrence_rule IceCube::Rule.daily.count(3)
+      occs = schedule.remaining_occurrences(t0 + IceCube::ONE_DAY + IceCube::ONE_HOUR, :spans => true)
+      expect(occs).to eq([t0 + IceCube::ONE_DAY, t0 + 2 * IceCube::ONE_DAY])
+    end
+
+    it 'should include occurrences with duration spanning the requested start time' do
+      t0 = Time.utc(2015, 10, 1, 15, 31)
+      schedule = IceCube::Schedule.new(t0, :duration => 30 * IceCube::ONE_DAY)
+      long_event = schedule.remaining_occurrences_enumerator(t0 + IceCube::ONE_DAY, :spans => true).take(1)
+      expect(long_event).to eq([t0])
+    end
+    
+    it 'should find occurrences between including previous one with duration spanning start' do
+      t0 = Time.utc(2015, 10, 1, 10, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_HOUR)
+      schedule.add_recurrence_rule IceCube::Rule.hourly.count(10)
+      occs = schedule.occurrences_between(t0 + IceCube::ONE_HOUR + 1, t0 + 3 * IceCube::ONE_HOUR + 1, :spans => true)
+      expect(occs.length).to eq(3)
+    end
+
+    it 'should include long occurrences starting before and ending after' do
+      t0 = Time.utc(2015, 10, 1, 00, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_DAY)
+      occs = schedule.occurrences_between(t0 + IceCube::ONE_HOUR, t0 + IceCube::ONE_DAY - IceCube::ONE_HOUR, :spans => true)
+      expect(occs).to eq([t0])
+    end
+
+    it 'should not find occurrence with duration ending on start time' do
+      t0 = Time.utc(2015, 10, 1, 12, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_HOUR)
+      expect(schedule.occurs_between?(t0 + IceCube::ONE_HOUR, t0 + 2 * IceCube::ONE_HOUR, :spans => true)).to be_falsey
+    end
+    
+    it 'should quickly fetch a future time from a recurring schedule' do
+      t0 = Time.utc(2000, 10, 1, 00, 00)
+      t1 = Time.utc(2015, 10, 1, 12, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_HOUR - 1)
+      schedule.add_recurrence_rule IceCube::Rule.hourly
+      occ = nil
+      timing = Benchmark.realtime do
+        occ = schedule.remaining_occurrences_enumerator(t1, :spans => true).take(1)
+      end
+      expect(timing).to be < 0.1
+      expect(occ).to eq([t1])
+    end
+    
+    it 'should not include occurrence ending on start time' do
+      t0 = Time.utc(2015, 10, 1, 10, 00)
+      schedule = IceCube::Schedule.new(t0, :duration => IceCube::ONE_HOUR / 2)
+      schedule.add_recurrence_rule IceCube::Rule.minutely(30).count(6)
+      third_occ = schedule.next_occurrence(t0 + IceCube::ONE_HOUR, :spans => true)
+      expect(third_occ).to eq(t0 + IceCube::ONE_HOUR)
+    end
+
+  end
+
   describe :previous_occurrence do
 
     it 'returns the previous occurrence for a time in the schedule' do
       t0 = Time.utc(2013, 5, 18, 12, 34)
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily
-      previous = schedule.previous_occurrence(t0 + 2 * ONE_DAY)
-      previous.should == t0 + ONE_DAY
+      previous = schedule.previous_occurrence(t0 + 2 * IceCube::ONE_DAY)
+      expect(previous).to eq(t0 + IceCube::ONE_DAY)
     end
 
     it 'returns nil given the start time' do
@@ -435,7 +544,15 @@ describe IceCube::Schedule do
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily
       previous = schedule.previous_occurrence(t0)
-      previous.should be_nil
+      expect(previous).to be_nil
+    end
+
+    it "should not skip back a day when called with a date" do
+      schedule = IceCube::Schedule.new(Time.utc(2014, 1, 1, 12, 34, 56)) do |s|
+        s.add_recurrence_rule IceCube::Rule.hourly
+      end
+      prev_hour = schedule.previous_occurrence(Date.new(2014, 1, 2))
+      expect( prev_hour ).to eq Time.utc(2014, 1, 1, 23, 34 , 56)
     end
 
   end
@@ -446,16 +563,16 @@ describe IceCube::Schedule do
       t0 = Time.utc(2013, 5, 18, 12, 34)
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily
-      previous = schedule.previous_occurrences(2, t0 + 3 * ONE_DAY)
-      previous.should == [t0 + ONE_DAY, t0 + 2 * ONE_DAY]
+      previous = schedule.previous_occurrences(2, t0 + 3 * IceCube::ONE_DAY)
+      expect(previous).to eq([t0 + IceCube::ONE_DAY, t0 + 2 * IceCube::ONE_DAY])
     end
 
     it 'limits the returned occurrences to a given count' do
       t0 = Time.utc(2013, 5, 18, 12, 34)
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily
-      previous = schedule.previous_occurrences(999, t0 + 2 * ONE_DAY)
-      previous.should == [t0, t0 + ONE_DAY]
+      previous = schedule.previous_occurrences(999, t0 + 2 * IceCube::ONE_DAY)
+      expect(previous).to eq([t0, t0 + IceCube::ONE_DAY])
     end
 
     it 'returns empty array given the start time' do
@@ -463,7 +580,16 @@ describe IceCube::Schedule do
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily
       previous = schedule.previous_occurrences(2, t0)
-      previous.should == []
+      expect(previous).to eq([])
+    end
+
+    it "should not skip back a day when called with a date" do
+      schedule = IceCube::Schedule.new(Time.utc(2014, 1, 1, 12, 34, 56)) do |s|
+        s.add_recurrence_rule IceCube::Rule.hourly
+      end
+      prev_hours = schedule.previous_occurrences(2, Date.new(2014, 1, 2))
+      expect( prev_hours ).to eq [Time.utc(2014, 1, 1, 22, 34 , 56),
+                                  Time.utc(2014, 1, 1, 23, 34 , 56)]
     end
 
   end
@@ -475,7 +601,7 @@ describe IceCube::Schedule do
       t1 = Time.utc(2013, 5, 31, 12, 34)
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily.until(t1 + 1)
-      schedule.last.should == t1
+      expect(schedule.last).to eq(t1)
     end
 
     it 'returns an array of occurrences given a number' do
@@ -483,24 +609,24 @@ describe IceCube::Schedule do
       t1 = Time.utc(2013, 5, 31, 12, 34)
       schedule = IceCube::Schedule.new(t0)
       schedule.add_recurrence_rule IceCube::Rule.daily.until(t1 + 1)
-      schedule.last(2).should == [t1 - ONE_DAY, t1]
+      expect(schedule.last(2)).to eq([t1 - IceCube::ONE_DAY, t1])
     end
 
     it 'raises an error for a non-terminating schedule' do
       schedule = IceCube::Schedule.new
       schedule.add_recurrence_rule IceCube::Rule.daily
-      expect { schedule.last }.to raise_error
+      expect { schedule.last }.to raise_error(ArgumentError)
     end
 
   end
 
-  describe :start_date= do
+  describe :start_time= do
 
     it 'should modify start date in rrule_occurrence_heads when changed' do
       schedule = IceCube::Schedule.new(Time.now - 1000)
       schedule.rrule IceCube::Rule.daily
-      schedule.start_time = (start_date = Time.now)
-      (Time.now - schedule.first.start_time).should be < 100
+      schedule.start_time = Time.now
+      expect(Time.now - schedule.first.start_time).to be < 100
     end
 
   end
@@ -510,7 +636,7 @@ describe IceCube::Schedule do
     it 'should not include rules for single occurrences' do
       schedule = IceCube::Schedule.new Time.now
       schedule.add_recurrence_time Time.now
-      schedule.rrules.should be_empty
+      expect(schedule.rrules).to be_empty
     end
 
   end
@@ -522,7 +648,7 @@ describe IceCube::Schedule do
       schedule.rrule IceCube::Rule.daily
       schedule.rrule IceCube::Rule.daily(2)
       schedule.remove_recurrence_rule schedule.rrules.first
-      schedule.rrules.count.should == 1
+      expect(schedule.rrules.count).to eq(1)
     end
 
     it 'should be able to remove multiple rules based on the comparator' do
@@ -530,7 +656,7 @@ describe IceCube::Schedule do
       schedule.rrule IceCube::Rule.daily
       schedule.rrule IceCube::Rule.daily
       schedule.remove_recurrence_rule schedule.rrules.first
-      schedule.rrules.should be_empty
+      expect(schedule.rrules).to be_empty
     end
 
     it 'should return the rule that was removed' do
@@ -538,47 +664,13 @@ describe IceCube::Schedule do
       rule = IceCube::Rule.daily
       schedule.rrule rule
       rule2 = schedule.remove_recurrence_rule rule
-      [rule].should == rule2
+      expect([rule]).to eq(rule2)
     end
 
     it 'should return [] if nothing was removed' do
       schedule = IceCube::Schedule.new Time.now
       rule = IceCube::Rule.daily
-      schedule.remove_recurrence_rule(rule).should == []
-    end
-
-  end
-
-  describe :remove_exception_rule do
-
-    it 'should be able to one rule based on the comparator' do
-      schedule = IceCube::Schedule.new Time.now
-      schedule.exrule IceCube::Rule.daily
-      schedule.exrule IceCube::Rule.daily(2)
-      schedule.remove_exception_rule schedule.exrules.first
-      schedule.exrules.count.should == 1
-    end
-
-    it 'should be able to remove multiple rules based on the comparator' do
-      schedule = IceCube::Schedule.new Time.now
-      schedule.exrule IceCube::Rule.daily
-      schedule.exrule IceCube::Rule.daily
-      schedule.remove_exception_rule schedule.exrules.first
-      schedule.exrules.should be_empty
-    end
-
-    it 'should return the rule that was removed' do
-      schedule = IceCube::Schedule.new Time.now
-      rule = IceCube::Rule.daily
-      schedule.exrule rule
-      rule2 = schedule.remove_exception_rule rule
-      [rule].should == rule2
-    end
-
-    it 'should return [] if nothing was removed' do
-      schedule = IceCube::Schedule.new Time.now
-      rule = IceCube::Rule.daily
-      schedule.remove_exception_rule(rule).should == []
+      expect(schedule.remove_recurrence_rule(rule)).to eq([])
     end
 
   end
@@ -590,19 +682,19 @@ describe IceCube::Schedule do
       schedule = IceCube::Schedule.new(time)
       schedule.add_recurrence_time time
       schedule.remove_recurrence_time time
-      schedule.recurrence_times.should be_empty
+      expect(schedule.recurrence_times).to be_empty
     end
 
     it 'should return the time that was removed' do
       schedule = IceCube::Schedule.new Time.now
       time = Time.now
       schedule.rtime time
-      schedule.remove_rtime(time).should == time
+      expect(schedule.remove_rtime(time)).to eq(time)
     end
 
     it 'should return nil if the date was not in the schedule' do
       schedule = IceCube::Schedule.new Time.now
-      schedule.remove_recurrence_time(Time.now).should be_nil
+      expect(schedule.remove_recurrence_time(Time.now)).to be_nil
     end
 
   end
@@ -614,19 +706,19 @@ describe IceCube::Schedule do
       schedule = IceCube::Schedule.new(time)
       schedule.extime time
       schedule.remove_exception_time time
-      schedule.exception_times.should be_empty
+      expect(schedule.exception_times).to be_empty
     end
 
     it 'should return the date that was removed' do
       schedule = IceCube::Schedule.new Time.now
       time = Time.now
       schedule.extime time
-      schedule.remove_extime(time).should == time
+      expect(schedule.remove_extime(time)).to eq(time)
     end
 
     it 'should return nil if the date was not in the schedule' do
       schedule = IceCube::Schedule.new Time.now
-      schedule.remove_exception_time(Time.now).should be_nil
+      expect(schedule.remove_exception_time(Time.now)).to be_nil
     end
 
   end
@@ -639,38 +731,38 @@ describe IceCube::Schedule do
       WORLD_TIME_ZONES.each do |zone|
         context "in #{zone}", :system_time_zone => zone do
           specify 'should determine if it occurs on a given Date' do
-            schedule.occurs_on?(Date.new(2010, 7, 1)).should be_false
-            schedule.occurs_on?(Date.new(2010, 7, 2)).should be_true
-            schedule.occurs_on?(Date.new(2010, 7, 3)).should be_false
+            expect(schedule.occurs_on?(Date.new(2010, 7, 1))).to be_falsey
+            expect(schedule.occurs_on?(Date.new(2010, 7, 2))).to be_truthy
+            expect(schedule.occurs_on?(Date.new(2010, 7, 3))).to be_falsey
           end
 
           specify 'should determine if it occurs on the day of a given UTC Time' do
-            schedule.occurs_on?(Time.utc(2010, 7, 1, 23, 59, 59)).should be_false
-            schedule.occurs_on?(Time.utc(2010, 7, 2,  0,  0,  1)).should be_true
-            schedule.occurs_on?(Time.utc(2010, 7, 2, 23, 59, 59)).should be_true
-            schedule.occurs_on?(Time.utc(2010, 7, 3,  0,  0,  1)).should be_false
+            expect(schedule.occurs_on?(Time.utc(2010, 7, 1, 23, 59, 59))).to be_falsey
+            expect(schedule.occurs_on?(Time.utc(2010, 7, 2,  0,  0,  1))).to be_truthy
+            expect(schedule.occurs_on?(Time.utc(2010, 7, 2, 23, 59, 59))).to be_truthy
+            expect(schedule.occurs_on?(Time.utc(2010, 7, 3,  0,  0,  1))).to be_falsey
           end
 
           specify 'should determine if it occurs on the day of a given local Time' do
-            schedule.occurs_on?(Time.local(2010, 7, 1, 23, 59, 59)).should be_false
-            schedule.occurs_on?(Time.local(2010, 7, 2,  0,  0,  1)).should be_true
-            schedule.occurs_on?(Time.local(2010, 7, 2, 23, 59, 59)).should be_true
-            schedule.occurs_on?(Time.local(2010, 7, 3,  0,  0,  1)).should be_false
+            expect(schedule.occurs_on?(Time.local(2010, 7, 1, 23, 59, 59))).to be_falsey
+            expect(schedule.occurs_on?(Time.local(2010, 7, 2,  0,  0,  1))).to be_truthy
+            expect(schedule.occurs_on?(Time.local(2010, 7, 2, 23, 59, 59))).to be_truthy
+            expect(schedule.occurs_on?(Time.local(2010, 7, 3,  0,  0,  1))).to be_falsey
           end
 
           specify 'should determine if it occurs on the day of a given non-local Time' do
-            schedule.occurs_on?(Time.new(2010, 7, 1, 23, 59, 59, "+11:15")).should be_false
-            schedule.occurs_on?(Time.new(2010, 7, 2,  0,  0,  1, "+11:15")).should be_true
-            schedule.occurs_on?(Time.new(2010, 7, 2, 23, 59, 59, "+11:15")).should be_true
-            schedule.occurs_on?(Time.new(2010, 7, 3,  0,  0,  1, "+11:15")).should be_false
+            expect(schedule.occurs_on?(Time.new(2010, 7, 1, 23, 59, 59, "+11:15"))).to be_falsey
+            expect(schedule.occurs_on?(Time.new(2010, 7, 2,  0,  0,  1, "+11:15"))).to be_truthy
+            expect(schedule.occurs_on?(Time.new(2010, 7, 2, 23, 59, 59, "+11:15"))).to be_truthy
+            expect(schedule.occurs_on?(Time.new(2010, 7, 3,  0,  0,  1, "+11:15"))).to be_falsey
           end
 
-          specify 'should determine if it occurs on the day of a given ActiveSupport::Time', :if_active_support_time => true do
+          specify 'should determine if it occurs on the day of a given ActiveSupport::Time', :requires_active_support => true do
             Time.zone = "Pacific/Honolulu"
-            schedule.occurs_on?(Time.zone.parse('2010-07-01 23:59:59')).should be_false
-            schedule.occurs_on?(Time.zone.parse('2010-07-02 00:00:01')).should be_true
-            schedule.occurs_on?(Time.zone.parse('2010-07-02 23:59:59')).should be_true
-            schedule.occurs_on?(Time.zone.parse('2010-07-03 00:00:01')).should be_false
+            expect(schedule.occurs_on?(Time.zone.parse('2010-07-01 23:59:59'))).to be_falsey
+            expect(schedule.occurs_on?(Time.zone.parse('2010-07-02 00:00:01'))).to be_truthy
+            expect(schedule.occurs_on?(Time.zone.parse('2010-07-02 23:59:59'))).to be_truthy
+            expect(schedule.occurs_on?(Time.zone.parse('2010-07-03 00:00:01'))).to be_falsey
           end
         end
       end
@@ -692,7 +784,7 @@ describe IceCube::Schedule do
         include_examples 'occurring on a given day'
       end
 
-      context 'starting from an ActiveSupport::Time', :if_active_support_time => true do
+      context 'starting from an ActiveSupport::Time', :requires_active_support => true do
         let(:start_time) { Time.new(2010, 7, 2, 10, 0, 0, '-07:00').in_time_zone('America/Vancouver') }
         include_examples 'occurring on a given day'
       end
@@ -713,15 +805,23 @@ describe IceCube::Schedule do
       include_examples :occurs_on?
     end
 
+    context 'across DST' do
+      let(:start_time) { Time.local(2010, 3, 2, 0, 0, 0) }
+      before { schedule.add_recurrence_rule(IceCube::Rule.monthly) }
+      it 'determines local midnight with time change' do
+        expect(schedule.occurs_on?(Date.new(2010, 7, 2))).to be_truthy
+      end
+    end
+
     it 'should be true for multiple rtimes' do
       schedule = IceCube::Schedule.new(Time.local(2010, 7, 10, 16))
       schedule.add_recurrence_time(Time.local(2010, 7, 11, 16))
       schedule.add_recurrence_time(Time.local(2010, 7, 12, 16))
       schedule.add_recurrence_time(Time.local(2010, 7, 13, 16))
 
-      schedule.occurs_on?(Date.new(2010, 7, 11)).should be_true
-      schedule.occurs_on?(Date.new(2010, 7, 12)).should be_true
-      schedule.occurs_on?(Date.new(2010, 7, 13)).should be_true
+      expect(schedule.occurs_on?(Date.new(2010, 7, 11))).to be_truthy
+      expect(schedule.occurs_on?(Date.new(2010, 7, 12))).to be_truthy
+      expect(schedule.occurs_on?(Date.new(2010, 7, 13))).to be_truthy
     end
 
   end
@@ -731,14 +831,14 @@ describe IceCube::Schedule do
     schedule.rrule IceCube::Rule.yearly(1)
     occurrence = schedule.next_occurrence
 
-    occurrence.dst?.should == start_time.dst? if start_time.respond_to? :dst?
-    occurrence.utc?.should == start_time.utc? if start_time.respond_to? :utc?
-    occurrence.zone.should == start_time.zone
+    expect(occurrence.dst?).to eq(start_time.dst?) if start_time.respond_to? :dst?
+    expect(occurrence.utc?).to eq(start_time.utc?) if start_time.respond_to? :utc?
+    expect(occurrence.zone).to eq(start_time.zone)
     occurrence.utc_offset == start_time.utc_offset
   end
 
   def trap_infinite_loop_beyond(iterations)
-    IceCube::ValidatedRule.any_instance.should_receive(:finds_acceptable_time?).
+    expect_any_instance_of(IceCube::ValidatedRule).to receive(:finds_acceptable_time?).
                           at_most(iterations).times.and_call_original
   end
 end
