@@ -5,19 +5,19 @@ describe IceCube::StringBuilder do
   describe :sentence do
 
     it 'should return empty string when none' do
-      IceCube::StringBuilder.sentence([]).should == ''
+      expect(IceCube::StringBuilder.sentence([])).to eq('')
     end
 
     it 'should return sole when one' do
-      IceCube::StringBuilder.sentence(['1']).should == '1'
+      expect(IceCube::StringBuilder.sentence(['1'])).to eq('1')
     end
 
     it 'should split on and when two' do
-      IceCube::StringBuilder.sentence(['1', '2']).should == '1 and 2'
+      expect(IceCube::StringBuilder.sentence(['1', '2'])).to eq('1 and 2')
     end
 
     it 'should comma and when more than two' do
-      IceCube::StringBuilder.sentence(['1', '2', '3']).should == '1, 2, and 3'
+      expect(IceCube::StringBuilder.sentence(['1', '2', '3'])).to eq('1, 2, and 3')
     end
 
   end
